CurlFeatureBits: Constants for libcurl

CurlFeatureBitsR Documentation

Constants for libcurl

Description

These are enums and bit fields defining constants used in libcurl and used in R to specify values symbolically.

Usage

CurlFeatureBits

Format

named integer vectors. The names give the symbolic constants that can be used in R and C code. These are mapped to their integer equivalents and used in C-level computations.

libcurl (see https://curl.se/)


RCurl documentation built on March 21, 2026, 5:07 p.m.

Related to CurlFeatureBits in RCurl...