AUTH: Constants for identifying Authentication Schemes

AUTH_ANYR Documentation

Constants for identifying Authentication Schemes

Description

These variables are symbolic constants that allow use to specify different combinations of schemes for HTTP authentication in a request to a Web server. We can combine them via the | operator to indicate that libcurl should try them in order until one works.

Examples

   AUTH_BASIC | AUTH_DIGEST

RCurl documentation built on March 21, 2026, 5:07 p.m.

Related to AUTH in RCurl...