A named character vector
giving the parameter values The names are the parameter names.
Arguments
query
the query string or full URL containing the query
isURL
a logical value. If TRUE, query is
the full URL and we need to extract the sub-string representing the
parameters. If isURL is FALSE, then query
is assumed to be just the string containing the parameters.